@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Annotation;
-$Config::Model::Annotation::VERSION = '2.133';
+package Config::Model::Annotation 2.138;
+
 use Mouse;
 use English;
 use Mouse::Util::TypeConstraints;
@@ -16,6 +16,7 @@ use Mouse::Util::TypeConstraints;
 use Path::Tiny;
 use Data::Dumper;
 
+use Config::Model::TypeConstraints;
 use Config::Model::Exception;
 use Config::Model::Node;
 use Config::Model::ObjTreeScanner;
@@ -34,7 +35,7 @@ has 'dir' => ( is => 'ro', isa => 'Path::Tiny', lazy => 1, builder => '_set_dir'
 
 has 'root_dir' => (
     is => 'ro',
-    isa => 'RootPath', # defined in Instance
+    isa => 'Config::Model::TypeContraints::Path',
     coerce => 1
 );
 
@@ -163,7 +164,7 @@ Config::Model::Annotation - Read and write configuration annotations
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -282,7 +283,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
