@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::AnyThing;
-$Config::Model::AnyThing::VERSION = '2.133';
+package Config::Model::AnyThing 2.138;
+
 use Mouse;
 
 # FIXME: must cleanup warp mechanism to implement this
@@ -198,7 +198,7 @@ sub annotation {
     my $self = shift;
     my $old_note = $self->{annotation} || '';
     if (@_ and not $self->instance->preset and not $self->instance->layered) {
-        my $new = $self->{annotation} = join( "\n", grep ( defined $_, @_ ) );
+        my $new = $self->{annotation} = join( "\n", grep { defined $_} @_ );
         $self->notify_change(note => 'updated annotation') unless $new eq $old_note;
     }
 
@@ -257,8 +257,14 @@ sub searcher {
 
 sub dump_as_data {
     my $self   = shift;
+    my %args = @_;
+    my $full = delete $args{full_dump} || 0;
+    if ($full) {
+        carp "dump_as_data: full_dump parameter is deprecated. Please use 'mode => user' instead";
+        $args{mode} //= 'user';
+    }
     my $dumper = Config::Model::DumpAsData->new;
-    $dumper->dump_as_data( node => $self, @_ );
+    $dumper->dump_as_data( node => $self, %args );
 }
 
 # hum, check if the check information is valid
@@ -327,7 +333,7 @@ Config::Model::AnyThing - Base class for configuration tree item
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -356,6 +362,11 @@ containing this object.
 Returns the node containing this object. May return undef if C<parent>
 is called on the root of the tree.
 
+=head2 container
+
+A bit like parent, this method returns the element containing this
+object. See L</container_type>
+
 =head2 container_type
 
 Returns the type (e.g. C<list> or C<hash> or C<leaf> or C<node> or
@@ -488,7 +499,7 @@ Forwarded to L<Config::Model::Instance/"root_path">.
 =head2 model_searcher
 
 Returns an object dedicated to search an element in the configuration
-model (respecting privilege level).
+model.
 
 This method returns a L<Config::Model::SearchElement> object. See
 L<Config::Model::Searcher> for details on how to handle a search.
@@ -524,7 +535,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
