@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Backend::Any;
-$Config::Model::Backend::Any::VERSION = '2.133';
+package Config::Model::Backend::Any 2.138;
+
 use Carp;
 use strict;
 use warnings;
@@ -163,7 +163,7 @@ sub write_global_comments {
     # write global comment
     my $global_note = $self->node->annotation;
     if ($global_note) {
-        map { $res .= "$cc $_\n" } split /\n/, $global_note;
+        for ( split /\n/, $global_note ) { $res .= "$cc $_\n" }
         $res .= "\n";
     }
 
@@ -187,7 +187,7 @@ sub write_data_and_comments {
     while (@data_and_comments) {
         my ( $d, $c ) = splice @data_and_comments, 0, 2;
         if ($c) {
-            map { $res .= "$cc $_\n" } split /\n/, $c;
+            for (split /\n/, $c ) { $res .= "$cc $_\n" }
         }
         $res .= "$d\n" if defined $d;
     }
@@ -213,7 +213,7 @@ Config::Model::Backend::Any - Virtual class for other backends
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -572,7 +572,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
