@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::BackendTrackOrder;
-$Config::Model::BackendTrackOrder::VERSION = '2.133';
+package Config::Model::BackendTrackOrder 2.138;
+
 # ABSTRACT: Track read order of elements from configuration
 
 use Mouse;
@@ -121,7 +121,9 @@ sub get_ordered_element_names {
     }
     else {
         # triggers a registration of all remaining elements in _creation_order
-        map { $self->register_element($_);} $self->get_element_names;
+        for ( $self->get_element_names ) {
+            $self->register_element($_);
+        }
         return $self->get_element_names_as_created;
     }
 }
@@ -140,7 +142,7 @@ Config::Model::BackendTrackOrder - Track read order of elements from configurati
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -217,7 +219,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
