@@ -7,7 +7,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Dumper 2.136;
+package Config::Model::Dumper 2.138;
 
 use Carp;
 use strict;
@@ -15,6 +15,7 @@ use warnings;
 
 use Config::Model::Exception;
 use Config::Model::ObjTreeScanner;
+use Config::Model::Value;
 
 sub new {
     bless {}, shift;
@@ -59,8 +60,8 @@ sub dump_tree {
     my $auto_v  = delete $args{auto_vivify} || 0;
     my $mode    = delete $args{mode} || '';
 
-    if ( $mode and $mode !~ /full|preset|custom|non_upstream_default/ ) {
-        croak "dump_tree: unexpected 'mode' value: $mode";
+    if ($full) {
+        carp "dump_tree: full_dump parameter is deprecated, please use mode => 'user'";
     }
 
     my $check = delete $args{check} || 'yes';
@@ -70,11 +71,15 @@ sub dump_tree {
 
     # mode parameter is slightly different from fetch's mode
     my $fetch_mode =
-          $full           ? ''
-        : $mode eq 'full' ? ''
+          $full           ? 'user'
+        : $mode eq 'full' ? 'user'
         : $mode           ? $mode
         :                   'custom';
 
+    if ( my $err = Config::Model::Value->is_bad_mode($fetch_mode) ) {
+        croak "dump_tree: $err";
+    }
+
     my $node = delete $args{node}
         || croak "dump_tree: missing 'node' parameter";
 
@@ -157,11 +162,9 @@ sub dump_tree {
 
             # skip undef values
             my @val = id_quote(
-                grep ( defined $_,
-                    $list_obj->fetch_all_values(
-                        mode  => $fetch_mode,
-                        check => $check
-                    ) ) );
+                grep { defined $_ }
+                    $list_obj->fetch_all_values(mode  => $fetch_mode, check => $check)
+                );
             $$data_r .= "\n$pad$element:=" . join( ',', @val ) if @val;
         }
     };
@@ -259,7 +262,7 @@ Config::Model::Dumper - Serialize data of config tree
 
 =head1 VERSION
 
-version 2.136
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -311,8 +314,8 @@ The serialization can be done in standard mode where only customized
 values are dumped in the string. I.e. only data modified by the user
 are dumped.
 
-The other mode is C<full_dump> mode where all all data, including
-default values, are dumped.
+All other mode supported by L<Config::Model::Value/fetch> can be used,
+for instance, to get default values.
 
 The serialized string can be used by L<Config::Model::Loader> to store
 the data back into a configuration tree.
@@ -342,12 +345,12 @@ Parameters are:
 
 =over
 
-=item mode ( full | preset | custom | non_upstream_default )
+=item mode
 
 C<full> dumps all configuration data including default
 values.
 
-C<preset> dumps only value entered in preset mode.
+All mode values from L<Config::Model::Value/fetch> can be used.
 
 By default, the dump contains only data modified by the user
 (i.e. C<custom> data that differ from default or preset values).
