@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Exception;
-$Config::Model::Exception::VERSION = '2.133';
+package Config::Model::Exception 2.138;
+
 use warnings;
 use strict;
 use Data::Dumper;
@@ -99,28 +99,28 @@ sub full_message {
     return $msg;
 }
 
-package Config::Model::Exception::Any;
-$Config::Model::Exception::Any::VERSION = '2.133';
+package Config::Model::Exception::Any 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception';
 
-package Config::Model::Exception::ModelDeclaration;
-$Config::Model::Exception::ModelDeclaration::VERSION = '2.133';
+package Config::Model::Exception::ModelDeclaration 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::Fatal';
 
 sub _desc {'configuration model declaration error' }
 
-package Config::Model::Exception::User ;
-$Config::Model::Exception::User::VERSION = '2.133';
+package Config::Model::Exception::User 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::Any';
 sub _desc {'user error' }
 
 
 ## old classes below
-package Config::Model::Exception::Syntax;
-$Config::Model::Exception::Syntax::VERSION = '2.133';
+package Config::Model::Exception::Syntax 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::Any';
 
@@ -140,8 +140,8 @@ sub full_message {
     return $msg;
 }
 
-package Config::Model::Exception::LoadData;
-$Config::Model::Exception::LoadData::VERSION = '2.133';
+package Config::Model::Exception::LoadData 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -155,17 +155,19 @@ sub full_message {
     my $obj      = $self->object;
     my $location = defined $obj ? $obj->name : '';
     my $msg      = "Configuration item ";
+    my $d = Data::Dumper->new( [ $self->wrong_data ], ['wrong data'] );
+    $d->Sortkeys(1);
     $msg .= "'$location' "                             if $location;
     $msg .= "(class " . $obj->config_class_name . ") " if $obj->get_type eq 'node';
     $msg .= "has a " . $self->description;
     $msg .= ":\n\t" . $self->error_or_msg . "\n";
-    $msg .= Data::Dumper->Dump( [ $self->wrong_data ], ['wrong data'] );
+    $msg .= $d->Dump;
 
     return $msg;
 }
 
-package Config::Model::Exception::Model;
-$Config::Model::Exception::Model::VERSION = '2.133';
+package Config::Model::Exception::Model 2.138;
+
 use Carp;
 use Mouse;
 extends 'Config::Model::Exception::Fatal';
@@ -199,8 +201,8 @@ sub full_message {
     return $msg;
 }
 
-package Config::Model::Exception::Load;
-$Config::Model::Exception::Load::VERSION = '2.133';
+package Config::Model::Exception::Load 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -228,8 +230,8 @@ sub full_message {
     return $msg;
 }
 
-package Config::Model::Exception::UnavailableElement;
-$Config::Model::Exception::UnavailableElement::VERSION = '2.133';
+package Config::Model::Exception::UnavailableElement 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -259,16 +261,16 @@ sub full_message {
     return $msg;
 }
 
-package Config::Model::Exception::AncestorClass;
-$Config::Model::Exception::AncestorClass::VERSION = '2.133';
+package Config::Model::Exception::AncestorClass 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::User';
 
 sub _desc { 'unknown ancestor class'}
 
 
-package Config::Model::Exception::ObsoleteElement;
-$Config::Model::Exception::ObsoleteElement::VERSION = '2.133';
+package Config::Model::Exception::ObsoleteElement 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -292,8 +294,8 @@ sub full_message {
     return $msg;
 }
 
-package Config::Model::Exception::UnknownElement;
-$Config::Model::Exception::UnknownElement::VERSION = '2.133';
+package Config::Model::Exception::UnknownElement 2.138;
+
 use Carp;
 
 use Mouse;
@@ -369,23 +371,23 @@ sub full_message {
     return $msg;
 }
 
-package Config::Model::Exception::WarpError;
-$Config::Model::Exception::WarpError::VERSION = '2.133';
+package Config::Model::Exception::WarpError 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::User';
 
 sub _desc { 'warp error'}
 
-package Config::Model::Exception::Fatal;
-$Config::Model::Exception::Fatal::VERSION = '2.133';
+package Config::Model::Exception::Fatal 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::Any';
 
 sub _desc { 'fatal error' }
 
 
-package Config::Model::Exception::UnknownId;
-$Config::Model::Exception::UnknownId::VERSION = '2.133';
+package Config::Model::Exception::UnknownId 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -418,16 +420,16 @@ sub full_message {
     return $msg;
 }
 
-package Config::Model::Exception::WrongValue;
-$Config::Model::Exception::WrongValue::VERSION = '2.133';
+package Config::Model::Exception::WrongValue 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::User';
 
 sub _desc { 'wrong value'};
 
 
-package Config::Model::Exception::WrongType;
-$Config::Model::Exception::WrongType::VERSION = '2.133';
+package Config::Model::Exception::WrongType 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -460,15 +462,15 @@ sub full_message {
     return $msg;
 }
 
-package Config::Model::Exception::ConfigFile;
-$Config::Model::Exception::ConfigFile::VERSION = '2.133';
+package Config::Model::Exception::ConfigFile 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::User';
 
 sub _desc { 'error in configuration file' }
 
-package Config::Model::Exception::ConfigFile::Missing;
-$Config::Model::Exception::ConfigFile::Missing::VERSION = '2.133';
+package Config::Model::Exception::ConfigFile::Missing 2.138;
+
 use Mouse;
 use Mouse::Util::TypeConstraints;
 
@@ -486,15 +488,15 @@ sub full_message {
     return "Error: cannot find configuration file " . $self->file . "\n";
 }
 
-package Config::Model::Exception::Formula;
-$Config::Model::Exception::Formula::VERSION = '2.133';
+package Config::Model::Exception::Formula 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::Model';
 
 sub _desc { 'error in computation formula of the configuration model'}
 
-package Config::Model::Exception::Internal;
-$Config::Model::Exception::Internal::VERSION = '2.133';
+package Config::Model::Exception::Internal 2.138;
+
 use Mouse;
 extends 'Config::Model::Exception::Fatal';
 
@@ -516,7 +518,7 @@ Config::Model::Exception - Exception mechanism for configuration model
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -574,7 +576,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
