@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2016 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::FuseUI;
-$Config::Model::FuseUI::VERSION = '2.097';
+package Config::Model::FuseUI 2.138;
+
 # there's no Singleton with Mouse
 use Mouse;
 
@@ -40,13 +40,13 @@ sub BUILD {
 # nodes, list and hashes are directories
 sub getdir {
     my $name = shift;
-    $logger->debug("FuseUI getdir called with $name");
+    $logger->trace("FuseUI getdir called with $name");
 
     my $obj = get_object($name);
     return -EINVAL() unless ( ref $obj and $obj->can('children') );
 
     my @c = ( '..', '.', $obj->children );
-    map { s(/)($dir_char_mockup)g } @c;
+    for (@c) { s(/)($dir_char_mockup)g };
     $logger->debug( "FuseUI getdir return @c , wantarray is " . ( wantarray ? 1 : 0 ) );
     return ( @c, 0 );
 }
@@ -92,7 +92,7 @@ sub _get_object {
 
 sub getattr {
     my $name = shift;
-    $logger->debug("FuseUI getattr called with $name");
+    $logger->trace("FuseUI getattr called with $name");
     my $obj = get_object($name);
 
     return -&ENOENT() unless ref $obj;
@@ -106,17 +106,17 @@ sub getattr {
         $size = length( fetch_as_line($obj) );
     }
     else {
+        # fuseui_obj->children does not return the right data in scalar context
         my @c = $obj->children;
-        map { s(/)($dir_char_mockup)g } @c;
         $size = @c;
     }
 
     my $mode;
     if ( $type eq 'leaf' or $type eq 'check_list' ) {
-        $mode = S_IFREG | 0644;
+        $mode = S_IFREG | oct(644);
     }
     else {
-        $mode = S_IFDIR | 0755;
+        $mode = S_IFDIR | oct(755);
     }
 
     my ( $dev, $ino, $rdev, $blocks, $gid, $uid, $nlink, $blksize ) =
@@ -140,7 +140,7 @@ sub open {
 
     # VFS sanity check; it keeps all the necessary state, not much to do here.
     my $name = shift;
-    $logger->debug("FuseUI open called on $name");
+    $logger->trace("FuseUI open called on $name");
     my $obj = $fuseui->root->get( path => $name, check => 'skip', get_obj => 1 );
     my $type = $obj->get_type;
 
@@ -156,7 +156,7 @@ sub read {
     # give a byte (ascii "0") to the reading program)
     my ( $name, $buf, $off ) = @_;
 
-    $logger->debug("FuseUI read called on $name");
+    $logger->trace("FuseUI read called on $name");
     my $obj  = get_or_create_object($name);
     my $type = $obj->get_type;
 
@@ -179,7 +179,7 @@ sub read {
 sub truncate {
     my ( $name, $off ) = @_;
 
-    $logger->debug("FuseUI truncate called on $name with length $off");
+    $logger->trace("FuseUI truncate called on $name with length $off");
     my $obj  = get_or_create_object($name);
     my $type = $obj->get_type;
 
@@ -188,7 +188,7 @@ sub truncate {
 
     my $v = substr fetch_as_line($obj), 0, $off;
 
-    $logger->debug( "FuseUI truncate stores '$v' of length ", length($v) );
+    $logger->trace( "FuseUI truncate stores '$v' of length ", length($v) );
 
     # store the value without any check. Check will be done in write()
     # the second parameter will trigger a notif_change.
@@ -199,10 +199,10 @@ sub truncate {
 sub write {
     my ( $name, $buf, $off ) = @_;
 
-    if ( $logger->is_debug ) {
+    if ( $logger->is_trace ) {
         my $str = $buf;
         $str =~ s/\n/\\n/g;
-        $logger->debug("FuseUI write called on $name with '$str' offset $off");
+        $logger->trace("FuseUI write called on $name with '$str' offset $off");
     }
 
     my $obj  = get_or_create_object($name);
@@ -228,7 +228,7 @@ sub mkdir {
     # give a byte (ascii "0") to the reading program)
     my ( $name, $mode ) = @_;
 
-    $logger->debug("FuseUI mkdir called on $name with mode $mode");
+    $logger->trace("FuseUI mkdir called on $name with mode $mode");
     my $obj = get_or_create_object($name);
     return -ENOENT() unless defined $obj;
 
@@ -244,7 +244,7 @@ sub rmdir {
     # give a byte (ascii "0") to the reading program)
     my ($name) = @_;
 
-    $logger->debug("FuseUI rmdir called on $name");
+    $logger->trace("FuseUI rmdir called on $name");
     my $obj = get_object($name);
     return -ENOENT() unless defined $obj;
 
@@ -327,7 +327,7 @@ Config::Model::FuseUI - Fuse virtual file interface for Config::Model
 
 =head1 VERSION
 
-version 2.097
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -387,7 +387,7 @@ empty and the old value is lost.
 
 =head1 constructor
 
-=head1 new (...)
+=head1 new
 
 parameters are:
 
@@ -407,7 +407,9 @@ Root of the configuration tree (C<Config::Model::Node> object )
 
 =head1 Methods
 
-=head2 run_loop( fork_in_loop => 1|0, debug => 1|0)
+=head2 run_loop
+
+Parameters: C<< ( fork_in_loop => 1|0, debug => 1|0 ) >>
 
 Mount the file system either in the current process or fork a new process before mounting the file system.
 In the former case, the call is blocking. In the latter case, the call returns after forking a process that
@@ -428,7 +430,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2016 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
