@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Instance;
-$Config::Model::Instance::VERSION = '2.133';
+package Config::Model::Instance 2.138;
+
 #use Scalar::Util qw(weaken) ;
 use strict;
 
@@ -22,6 +22,7 @@ use File::Path;
 use Path::Tiny;
 use Log::Log4perl qw(get_logger :levels);
 
+use Config::Model::TypeConstraints;
 use Config::Model::Exception;
 use Config::Model::Node;
 use Config::Model::Loader;
@@ -236,21 +237,12 @@ has [qw/name application backend backend_arg backup/] => (
     isa => 'Maybe[Str]',
 );
 
-subtype 'RootPath' => as 'Maybe[Path::Tiny]' ;
-coerce 'RootPath' => from 'Str' => via sub { defined $_ ?  Path::Tiny::path($_) : undef ; } ;
-
 has 'root_dir' => (
     is => 'ro',
-    isa => 'RootPath',
+    isa => 'Config::Model::TypeContraints::Path',
     coerce => 1
 );
 
-sub read_root_dir {
-    my $self = shift;
-    carp "deprecated";
-    return $self->root_dir;
-}
-
 has root_path => (
     is  => 'ro',
     isa => 'Path::Tiny',
@@ -263,24 +255,31 @@ sub _build_root_path {
     return $root_dir ? path($root_dir) : Path::Tiny->cwd;
 }
 
-# config_file cannot be a Path::Tiny object: it may be a file name
-# relative to a directory only known by a backend (e.g. a patch in
-# debian/patches directory)
-# TODO: the above argument goes down if debian/patch uses backend_arg
-has config_file => (is  => 'ro', isa => 'Maybe[Str]');
-
-has config_dir => (is  => 'ro', isa => 'Maybe[Str]');
+has [qw/config_dir config_file/] => (
+    is  => 'ro',
+    isa => 'Config::Model::TypeContraints::Path',
+    coerce => 1
+);
 
 has tree => (
     is      => 'ro',
     isa     => 'Config::Model::Node',
-    builder => 'reset_config',
+    builder => '_build_tree',
+    lazy    => 1,
+    clearer => '_clear_config',
     reader  => 'config_root',
     handles => [qw/apply_fixes deep_check grab grab_value/],
 );
 
 sub reset_config {
     my $self = shift;
+    $self->_clear_config;
+    $self->clear_changes;
+    return $self->config_root;
+}
+
+sub _build_tree {
+    my $self = shift;
 
     return $self->load_node (
         config_class_name => $self->{root_class_name},
@@ -389,7 +388,7 @@ sub modify {
 
 sub load {
     my $self   = shift;
-    my $loader = Config::Model::Loader->new( start_node => $self->{tree} );
+    my $loader = Config::Model::Loader->new( start_node => $self->config_root );
     my %args   = @_ eq 1 ? ( step => $_[0] ) : @_;
     $loader->load( %args );
     return $self;
@@ -397,7 +396,7 @@ sub load {
 
 sub search_element {
     my $self = shift;
-    $self->{tree}->search_element(@_);
+    $self->config_root->search_element(@_);
 }
 
 sub wizard_helper {
@@ -586,7 +585,7 @@ sub _write_back_node {
 
         if (defined $node and ($node->needs_save or $force_write)) {
             my $dir = $args{config_dir};
-            mkpath( $dir, 0, 0755 ) if $dir and not -d $dir;
+            mkpath( $dir, 0, oct(755) ) if $dir and not -d $dir;
 
             my $res ;
             if (not $force_backend
@@ -662,7 +661,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -743,7 +742,7 @@ supplied if not provided by the configuration model. (string)
 
 =item backend
 
-Specify which backend to use. See L</write_back ( ... )> for details
+Specify which backend to use. See L</write_back> for details
 
 =item backend_arg
 
@@ -823,7 +822,9 @@ Returns <$self>.
 =head2 save
 
 Save the content of the configuration tree to
-configuration files. (alias to C<write_back>)
+configuration files. (See L</write_back> for more details)
+
+Use C<< force => 1 >> option to force saving configuration data.
 
 =head2 config_root
 
@@ -885,7 +886,7 @@ L<Config::Model::Role::Grab/grab_value>
 =head2 searcher
 
 Returns an object dedicated to search an element in the configuration
-model (respecting privilege level).
+model.
 
 This method returns a L<Config::Model::Searcher> object. See
 L<Config::Model::Searcher> for details on how to handle a search.
@@ -1069,6 +1070,10 @@ specifications.
 
 C<write_back> croaks if no write call-back are known.
 
+Use C<< force => 1 >> option to force saving configuration data. This
+is useful to write back a file even no change are done at semantic
+level, i.e. to reformat a file or remove unnecessary data.
+
 =head1 AUTHOR
 
 Dominique Dumont, (ddumont at cpan dot org)
@@ -1087,7 +1092,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
