@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Role::ComputeFunction;
-$Config::Model::Role::ComputeFunction::VERSION = '2.133';
+package Config::Model::Role::ComputeFunction 2.138;
+
 # ABSTRACT: compute &index or &element functions
 
 use Mouse::Role;
@@ -31,7 +31,7 @@ sub eval_function {
     my ($self, $function, $up, $check) = @_;
 
     if (defined $up) {
-        # get now the object refered
+        # get now the object referred
         $up =~ s/\s//g;
         $up =~ s/-(\d+)/'- ' x $1/e;        # change  -3 -> - - -
         $up =~ s/(-+)/'- ' x length($1)/e;  # change --- -> - - -
@@ -90,7 +90,7 @@ Config::Model::Role::ComputeFunction - compute &index or &element functions
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -147,7 +147,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
