@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::SearchElement;
-$Config::Model::SearchElement::VERSION = '2.133';
+package Config::Model::SearchElement 2.138;
+
 use Log::Log4perl qw(get_logger :levels);
 use Carp;
 use strict;
@@ -30,11 +30,9 @@ sub new {
 
     bless $self, $type;
 
-    $self->{privilege} = $args{privilege} || 'master';
-
     my $root_class = $self->{node}->config_class_name;
 
-    $self->{data} = $self->_sniff_class( $root_class, $self->{privilege}, {} );
+    $self->{data} = $self->_sniff_class( $root_class, {} );
 
     return $self;
 }
@@ -43,12 +41,12 @@ sub new {
 # either Data::Dumper or Tk::ObjScanner (both are available on CPAN)
 
 sub _sniff_class {
-    my ( $self, $class, $privilege, $found_ref ) = @_;
+    my ( $self, $class, $found_ref ) = @_;
 
     my @lines;
     my %h;
     my $model   = $self->{model};
-    my $c_model = $model->get_model($class);
+    my $c_model = $model->get_model_clone($class);
 
     $logger->trace("sniffing config class $class");
 
@@ -76,11 +74,11 @@ sub _sniff_class {
             or $c_type =~ /(warped_)?node/ ) {
             my $tmp =
                   $element_type eq 'node' || $c_type eq 'node'
-                ? $self->_sniff_class( $cfg_class_name, $privilege, \%local_found )
-                : $self->_sniff_warped_node( $element_model, $privilege, \%local_found );
+                ? $self->_sniff_class( $cfg_class_name, \%local_found )
+                : $self->_sniff_warped_node( $element_model, \%local_found );
 
             # merge all tmp in %h
-            map { $h{$_}{next_step}{$element} = $tmp->{$_}; } keys %$tmp;
+            for (keys %$tmp) { $h{$_}{next_step}{$element} = $tmp->{$_}; }
         }
         else {
             $h{$element}{next_step}{$element} = '';
@@ -91,7 +89,7 @@ sub _sniff_class {
 }
 
 sub _sniff_warped_node {
-    my ( $self, $element_model, $privilege, $found_ref ) = @_;
+    my ( $self, $element_model, $found_ref ) = @_;
 
     my %warp_tmp;
     my $ref = $element_model->{warp}{rules};
@@ -103,10 +101,10 @@ sub _sniff_warped_node {
 
         # sniff all classes mentionned in warped node rules
         my %local_found = %$found_ref;
-        my $tmp = $self->_sniff_class( $sub_class, $privilege, \%local_found );
+        my $tmp = $self->_sniff_class( $sub_class, \%local_found );
 
         # merge all tmp in %warp_tmp
-        map { $warp_tmp{$_}{next_class}{$sub_class} = $tmp->{$_}; } keys %$tmp;
+        for ( keys %$tmp ) { $warp_tmp{$_}{next_class}{$sub_class} = $tmp->{$_}; }
     }
 
     return \%warp_tmp;
@@ -191,8 +189,6 @@ sub next_choice {
 
 }
 
-# TBD if choice is an id, Node is a hash...
-
 sub choose {
     my $self   = shift;
     my $choice = shift;
@@ -333,7 +329,7 @@ Config::Model::SearchElement - Search an element in a configuration model
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -585,7 +581,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
