@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::TermUI;
-$Config::Model::TermUI::VERSION = '2.133';
+package Config::Model::TermUI 2.138;
+
 use Carp;
 use utf8;      # so literals and identifiers can be in UTF-8
 use v5.12;     # or later to get "unicode_strings" feature
@@ -25,7 +25,7 @@ my $completion_sub = sub {
     my ( $self, $text, $line, $start ) = @_;
 
     my @choice = $self->{current_node}->get_element_name;
-    my @ret = grep( /^$text/, @choice );
+    my @ret = grep { /^$text/ } @choice ;
     return @ret;
 };
 
@@ -33,7 +33,7 @@ my $leaf_completion_sub = sub {
     my ( $self, $text, $line, $start ) = @_;
 
     my @choice = $self->{current_node}->get_element_name( cargo_type => 'leaf' );
-    my @ret = grep( /^$text/, @choice );
+    my @ret = grep { /^$text/ } @choice ;
     return @ret;
 };
 
@@ -42,7 +42,7 @@ my $fix_completion_sub = sub {
 
     my @choice = $self->{current_node}->get_element_name;
     push @choice, '!';
-    my @ret = grep( /^$text/, @choice );
+    my @ret = grep { /^$text/ } @choice ;
     return @ret;
 };
 
@@ -51,7 +51,7 @@ my $ll_completion_sub = sub {
 
     my @choice = $self->{current_node}->get_element_name;
     push @choice, '-nz';
-    my @ret = grep( /^$text/, @choice );
+    my @ret = grep { /^$text/ } @choice ;
     return @ret;
 };
 
@@ -105,7 +105,7 @@ my $cd_completion_sub = sub {
     }
 
     # filter possible choices according to input
-    my @ret = grep( /^$text/, @choice );
+    my @ret = grep { /^$text/ } @choice ;
 
     #print "->choice +",join('+',@ret),"+ text:'$text'<-\n";
 
@@ -138,7 +138,7 @@ sub completion {
         return $completion_dispatch{$main}->( $self, $text, $line, $start );
     }
     elsif ( not $cmd ) {
-        return grep ( /^$text/, $self->simple_ui_commands() );
+        return grep { /^$text/ } $self->simple_ui_commands() ;
     }
 
     return ();
@@ -238,7 +238,7 @@ Config::Model::TermUI - Interactive command line interface for cme
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -411,7 +411,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
