@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::ValueComputer;
-$Config::Model::ValueComputer::VERSION = '2.133';
+package Config::Model::ValueComputer 2.138;
+
 use Mouse;
 use MouseX::StrictConstructor;
 
@@ -135,7 +135,7 @@ sub compute {
             my $formula = $pre_formula;
             $formula =~ s/\$([_a-zA-Z]\w*)/defined $__vars{$1} ? "\$__vars{$1}" : "\$$1" /eg;
             $logger->debug("compute: evaluating '$formula'");
-            $result = eval $formula;
+            $result = eval $formula; ## no critic (ProhibitStringyEval)
             if ($@) {
                 Config::Model::Exception::Formula->throw(
                     object => $self->{value_object},
@@ -550,7 +550,7 @@ Config::Model::ValueComputer - Provides configuration value computation
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -922,7 +922,7 @@ Extract the host name from an URL:
      },
  },
 
-=head2 simple copy hash example
+=head2 copy hash example
 
 Copying a hash may not be useful, but the using C<&index()> in a variable can be. Here's an example
 where the hashes contain leaves.
@@ -973,7 +973,7 @@ the data to be copied is stored within a node. The main class has 2 hash element
             },
         },
 
-The Class to copy from is quite simple:
+The Class to copy from is quite short:
 
     'name' => 'From',
     'element' => [
@@ -1015,7 +1015,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
