@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Warper;
-$Config::Model::Warper::VERSION = '2.133';
+package Config::Model::Warper 2.138;
+
 use Mouse;
 
 use Log::Log4perl qw(get_logger :levels);
@@ -452,7 +452,7 @@ sub compute_bool {
     {
         my $warped_obj = $self->warped_object ;
         no warnings "uninitialized";
-        $ret = eval($perl_code);
+        $ret = eval($perl_code); ## no critic (ProhibitStringyEval)
     }
 
     if ($@) {
@@ -623,7 +623,7 @@ Config::Model::Warper - Warp tree properties
 
 =head1 VERSION
 
-version 2.133
+version 2.138
 
 =head1 SYNOPSIS
 
@@ -877,7 +877,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
