@@ -1,15 +1,18 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 # test model used by t/*.t
+use strict;
+use warnings;
 
-[
+
+return [
     {
         rw_config => {
             backend     => 'IniFile',
