@@ -1,18 +1,16 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
+use strict;
+use warnings;
 
-$conf_file_name = "fstab" ;
-$conf_dir = "etc" ;
-$model_to_test = "Fstab" ;
-
-@tests = (
+my @tests = (
     { # t0
      check => { 
        'fs:/proc fs_spec',           "proc" ,
@@ -32,4 +30,9 @@ $model_to_test = "Fstab" ;
      },
 );
 
-1;
+return {
+    model_to_test => "Fstab",
+    conf_file_name => "fstab",
+    conf_dir => "etc",
+    tests => \@tests
+};
