@@ -1,13 +1,16 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-{
+use strict;
+use warnings;
+
+return {
 	set_in_etc => 'system value',
 	set_in_both => 'system value2',
 	a_checklist  => {qw/c 1 d 0 e 1/}
