@@ -1,12 +1,15 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2016 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
+use strict;
+use warnings;
+
 {
 	set_by_user => 'user value',
 	set_in_both => 'user value2',
