@@ -1,25 +1,25 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2016 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
+use strict;
+use warnings;
 
-$model_to_test = "Multistrap";
-
-$from_scratch_file = <<'EOF' ;
+my $from_scratch_file = <<'EOF' ;
 ## This file was written by cme command.
 ## You can run 'cme edit multistrap' to modify this file.
 ## You may also modify the content of this file with your favorite editor.
 
 [general]
-include=/usr/share/multistrap/crosschroot.conf
+include = /usr/share/multistrap/crosschroot.conf
 EOF
 
-@tests = (
+my @tests = (
     {
         name        => 'arm',
         config_file => '/home/foo/my_arm.conf',
@@ -56,8 +56,15 @@ EOF
         name => 'igep0020',
         config_file => '/home/foo/strap-igep0020.conf',
         load_check => 'skip',
-        load_warnings => [ qr/deprecated/, (qr/deprecated/, qr/skipping/) x2 ]
+        log4perl_load_warnings => [
+            [ 'User', warn => qr/deprecated/ ]  ,
+            [ 'User' , ( warn => qr/skipping/) x 2 ]
+        ],
     },
 );
 
-1;
+return {
+    model_to_test => "Multistrap",
+    tests => \@tests
+};
+
